#!/usr/bin/env node
import chalk from 'chalk';
import semver from 'semver';

import { execute } from './execute';
import { prompt } from './prompt';

const validNodeVersion = () => semver.gte(process.version, '10.12.0');

const warnNodeVer = () => {
  console.log(chalk.bgRed('\nUh oh! Looks like you dont have Node >= 10.12.0 installed!\n'));
  console.log(`You can solve this by running:`);
  console.log(`  $ nvm install node ${chalk.gray(`# "node" is an alias for the latest version`)}`);
  console.log(`  $ nvm use node`);
};

function exitNicely(error) {
  console.error(error);
  process.exit(1);
}

(async function main() {
  if (!validNodeVersion()) return warnNodeVer();
  return await Promise.resolve()
    .then(prompt)
    .then(execute);
})().catch(exitNicely);
